MetersetMap Comparison
======================

For the time being this GUI utility is undocumented. For more information see
the `discussions within the mailing list
<https://groups.google.com/g/pymedphys/c/2LczVpmc_Ak/m/ljmMDqekAAAJ>`__.
